package com.s3ai.corporate_app2

import com.s3ai.corporate_app2.controllers.UsersController
import org.assertj.core.api.Assertions.assertThat
import org.junit.jupiter.api.Test
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.boot.test.context.SpringBootTest
import org.springframework.ui.ExtendedModelMap
import java.util.*


@SpringBootTest
class UsersApiTest {
    @Autowired
    private lateinit var controller: UsersController

    @Test
    @Throws(Exception::class)
    fun contextLoads() {
        assertThat(controller).isNotNull
    }

    @Test
    @Throws(Exception::class)
    fun shouldUpdateCinema() {
        val user = User()
        val id = UUID.randomUUID()
        user.id = id
        user.name = "test"
        controller.updateUser(user)
        val userFromBase = controller.userService.findById(id)
        assertThat(userFromBase?.equals(user))
    }

    @Test
    @Throws(Exception::class)
    fun shouldRedirectToCreateUserIfIdNotExists() {
        val model = ExtendedModelMap()
        val redirect = controller.getUserEditPage(UUID.randomUUID().toString(), model)
        assertThat(redirect.equals("users/edit"))
        assertThat(model.getValue("action") == "Create")
    }

    @Test
    @Throws(Exception::class)
    fun shouldRedirectToEditCinemaIfIdExists() {
        val user = User()
        val id = UUID.randomUUID()
        user.id = id
        user.name = "test"
        controller.updateUser(user)
        val model = ExtendedModelMap()
        val redirect = controller.getUserEditPage(id.toString(), model)
        assertThat(redirect.equals("users/edit"))
        assertThat(model.getValue("action") == "Edit")
    }

    @Test
    @Throws(Exception::class)
    fun shouldReturnUsersBrowsePage() {
        val user = User()
        val id = UUID.randomUUID()
        user.id = id
        user.name = "test"
        controller.updateUser(user)
        val model = ExtendedModelMap()
        val redirect = controller.getUsersBrowsePage(model)
        assertThat(redirect.equals("users/list"))
        assertThat(model.getValue("users")).isNotNull
    }
}
